==> alfr_1.1.0.tar.gz: alfr/tests/api/authentication/versions/1/tickets-7b9af9-POST.R <==
structure(list(url = "http://localhost:8080/alfresco/api/-default-/public/authentication/versions/1/tickets", 
    status_code = 201L, headers = structure(list(server = "Apache-Coyote/1.1", 
        `cache-control` = "no-cache", expires = "Thu, 01 Jan 1970 00:00:00 GMT", 
        pragma = "no-cache", `content-type` = "application/json;charset=UTF-8", 
        `content-length` = "83", date = "Fri, 17 May 2019 03:51:40 GMT"), class = c("insensitive", 
    "list")), all_headers = list(list(status = 201L, version = "HTTP/1.1", 
        headers = structure(list(server = "Apache-Coyote/1.1", 
            `cache-control` = "no-cache", expires = "Thu, 01 Jan 1970 00:00:00 GMT", 
            pragma = "no-cache", `content-type` = "application/json;charset=UTF-8", 
            `content-length` = "83", date = "Fri, 17 May 2019 03:51:40 GMT"), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = charToRaw("{\"entry\":{\"id\":\"TICKET_a526a4eddbdce93e59a00942909dc4f8a1e4e649\",\"userId\":\"admin\"}}"), 
    date = structure(1558065100, class = c("POSIXct", "POSIXt"
    ), tzone = "GMT"), times = c(redirect = 0, namelookup = 1e-06, 
    connect = 1e-06, pretransfer = 1e-06, starttransfer = 1e-06, 
    total = 0)), class = "response")

==> alfr_1.2.1.tar.gz: alfr/tests/api/authentication/versions/1/tickets-7b9af9-POST.R <==
structure(list(url = "http://localhost:8080/alfresco/api/-default-/public/authentication/versions/1/tickets", 
    status_code = 201L, headers = structure(list(server = "Apache-Coyote/1.1", 
        `cache-control` = "no-cache", expires = "Thu, 01 Jan 1970 00:00:00 GMT", 
        pragma = "no-cache", `content-type` = "application/json;charset=UTF-8", 
        `content-length` = "83", date = "Tue, 09 Jul 2019 03:36:42 GMT"), class = c("insensitive", 
    "list")), all_headers = list(list(status = 201L, version = "HTTP/1.1", 
        headers = structure(list(server = "Apache-Coyote/1.1", 
            `cache-control` = "no-cache", expires = "Thu, 01 Jan 1970 00:00:00 GMT", 
            pragma = "no-cache", `content-type` = "application/json;charset=UTF-8", 
            `content-length` = "83", date = "Tue, 09 Jul 2019 03:36:42 GMT"), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = charToRaw("{\"entry\":{\"id\":\"TICKET_43bbd1798d1db6d5195c6d1bc0b504f511a864b7\",\"userId\":\"admin\"}}"), 
    date = structure(1562643402, class = c("POSIXct", "POSIXt"
    ), tzone = "GMT"), times = c(redirect = 0, namelookup = 1e-06, 
    connect = 1e-06, pretransfer = 1e-06, starttransfer = 1e-06, 
    total = 0)), class = "response")
